Index: src/spaces.cc |
diff --git a/src/spaces.cc b/src/spaces.cc |
index e7cb8ccf85254003af635e44c2fe81d582e2b926..2ca315eedcb685212e50f0421bb9d05a6e81f628 100644 |
--- a/src/spaces.cc |
+++ b/src/spaces.cc |
@@ -3062,10 +3062,12 @@ void LargeObjectSpace::Verify() { |
// We have only code, sequential strings, external strings |
// (sequential strings that have been morphed into external |
// strings), fixed arrays, and byte arrays in large object space. |
Hannes Payer (out of office)
2014/07/16 15:23:28
"," before and
rmcilroy
2014/07/16 15:30:40
https://www.youtube.com/watch?v=P_i1xk07o4g :)
Do
|
+ // large object space. |
CHECK(object->IsCode() || object->IsSeqString() || |
- object->IsExternalString() || object->IsFixedArray() || |
- object->IsFixedDoubleArray() || object->IsByteArray()); |
+ object->IsExternalString() || object->IsFixedArray() || |
+ object->IsFixedDoubleArray() || object->IsByteArray() || |
+ object->IsConstantPoolArray()); |
// The object itself should look OK. |
object->ObjectVerify(); |
@@ -3062,10 +3062,12 @@ void LargeObjectSpace::Verify() { |
// We have only code, sequential strings, external strings |
// (sequential strings that have been morphed into external |
- // strings), fixed arrays, and byte arrays in large object space. |
+ // strings), fixed arrays, byte arrays and constant pool arrays in the |
Hannes Payer (out of office)
2014/07/16 15:23:28